==> speech-analytic-testing_5.2.10_database.tar.gz: database/mssql/procedures/ReportBySummaryAgent.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE [dbo].[ReportBySummaryAgent] (
	@VCC varchar(50) = NULL, 
	@HistoricCampaign varchar(MAX) = NULL, 
	@Plan varchar(MAX) = NULL,
	@Format varchar(MAX) , 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(MAX) = NULL ,
	@IdAgente varchar(MAX) = NULL
) AS
  DECLARE @cols varchar(max)
  DECLARE @query varchar(max)
  --ReportBySummaryAgent 'allegro','entrantes',NULL,'nov01-0356',NULL,NULL,NULL,NULL
  --SET @Format = 'nov01-0356'
  SET NOCOUNT ON
  
  SELECT
    * INTO #TempEvaluationResult
  FROM (
  SELECT
    EP.Description AS 'DescriptionPlan',
    EF.Description AS 'DescriptionFormat',
    GP.Description + '-' + SGP.Description + '-' + A.Title AS 'Ability',
    ER.AgentDescription,
    ER.CampaignDescription,
    ER.IdInteraction,
    ER.Qualification,
    Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss') AS 'EvaluationDate',
    ER.IdAuditor,
    EP.Evaluation_Mode
  FROM EvaluationResult (NOLOCK) ER
  LEFT JOIN HistoricEvaluationFormat (NOLOCK) EF
    ON ER.IdEvaluationFormat = EF.ID AND ER.IdEvaluationPlan = EF.EvaluationPlanId
  LEFT JOIN HistoricAbility (NOLOCK) A
    ON A.ID = ER.IdAbility AND ER.IdEvaluationPlan = A.EvaluationPlanId
  LEFT JOIN EvaluationPlan (NOLOCK) EP
    ON EP.ID = ER.IdEvaluationPlan
  LEFT JOIN [HistoricGroup] (NOLOCK) GP
    ON GP.ID = ER.IdGroup AND EP.ID = GP.EvaluationPlanId
  LEFT JOIN HistoricSubGroup SGP (NOLOCK)
    ON SGP.ID = ER.IdSubGroup AND EP.ID = SGP.EvaluationPlanId
  WHERE 
   EF.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Format IS NULL,EF.Description,@Format),','))
  AND ER.Instance LIKE CASE
    WHEN @VCC IS NOT NULL THEN @VCC
    ELSE ER.Instance
  END
  AND 
  EP.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Plan IS NULL,EP.Description,@Plan),','))
  AND
  ER.CampaignDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@HistoricCampaign IS NULL,ER.CampaignDescription,@HistoricCampaign),','))
  AND 
  ER.AgentDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAgente IS NULL,ER.AgentDescription,@IdAgente),','))
  AND 
  ER.IdAuditor IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAuditor IS NULL,ER.IdAuditor,@IdAuditor),','))
  AND ER.EvaluationDate >=
                          CASE
                            WHEN @StartDate IS NOT NULL THEN @StartDate
                            ELSE '19800101'
                          END
  AND ER.EvaluationDate <
                         CASE
                           WHEN @EndDate IS NOT NULL THEN @EndDate + ' 23:59'
                           ELSE '20500101'
                         END
	) a

	
	SET @cols = STUFF(
		(
			SELECT (',' + QUOTENAME(TMP_ER.[Ability]))
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')
  
  IF @cols IS NOT NULL
  BEGIN
    ------
    DECLARE @type varchar(max) = (SELECT TOP 1
      Evaluation_Mode
    FROM #TempEvaluationResult)
	
	-------
    DECLARE @Total varchar(max) = STUFF(
		(
			SELECT '+ ISNULL(' + QUOTENAME(TMP_ER.[Ability]) + ',0)'
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')    
	
	-- ROUND(AVG(CAST(ER.Qualification AS float)), 2) AS 'Qualification',
    DECLARE @colavg varchar(max) = STUFF(
		(
			SELECT ', ROUND(AVG(CAST(q.' + QUOTENAME(TMP_ER.[Ability]) + ' AS float)), 2) As [' + TMP_ER.[Ability] + ' Promedio]'
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')
	
	--SELECT @colavg
    IF @type = 'M'
    BEGIN
      SET @query = ' 
				Select 
				q.DescriptionPlan As   [EVALUATION_PLAN] ,
				q.DescriptionFormat As [EVALUATION_FORMAT] ,
				q.AgentDescription As  [AGENT] ,
				q.CampaignDescription As [CAMPAIGN] ,
				count(q.IdInteraction) As [AUDITS],
				sum(q.DurationTime) As [DURATION_TIME],
				ROUND(AVG(CAST(q.Note AS float)), 2) As [AVERAGE_SCORE],
				' + @colavg + ' From
				(Select p.DescriptionPlan,p.DescriptionFormat,p.AgentDescription,
  				p.CampaignDescription,p.IdInteraction,p.EvaluationDate,p.IdAuditor,InteractionDuration as DurationTime, 
				null As Number,InteractionDateStart As StartDate,null As Category1,(' + @Total + ') As Note, ' + @cols + ' from 
				( select DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock)
				) as A On
				A.IdInteraction=p.IdInteraction)q
				Group By 
				q.DescriptionPlan,q.DescriptionFormat,q.AgentDescription,q.CampaignDescription
				'
    END
    ELSE
    BEGIN
      SET @query = '
	
			    Select 
				q.DescriptionPlan As   [EVALUATION_PLAN] ,
				q.DescriptionFormat As [EVALUATION_FORMAT] ,
				q.AgentDescription As  [AGENT] ,
				q.CampaignDescription As [CAMPAIGN] ,
			    count(q.IdInteraction) As [AUDITS],
				sum(q.DurationTime) As [DURATION_TIME],
				ROUND(AVG(CAST(q.Note AS float)), 2) As [AVERAGE_SCORE],
				' + @colavg + '
				From 
				(Select p.DescriptionPlan,p.DescriptionFormat,p.AgentDescription,
  				p.CampaignDescription,p.IdInteraction,p.EvaluationDate,p.IdAuditor,
				A.DurationTime,A.Number,A.StartDate,A.Category1,(' + @Total + ') As Note, ' + @cols + ' from 
				( select DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join Audio as A On
				A.ID=p.IdInteraction)q
				Group By 
				q.DescriptionPlan,q.DescriptionFormat,q.AgentDescription,q.CampaignDescription'
    END
    --Print(@query)
    EXECUTE (@query)
    --Select * From @query
	

    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    DROP TABLE #TempEvaluationResult
    SELECT
						''				As [EVALUATION_PLAN],
						''				As [EVALUATION_FORMAT],
						''				As [AGENT],
  						''			    As [CAMPAIGN] 
  END
  
  SET NOCOUNT OFF
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/ReportBySummaryAgent.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE [dbo].[ReportBySummaryAgent] (
	@VCC varchar(50) = NULL, 
	@HistoricCampaign varchar(MAX) = NULL, 
	@Plan varchar(MAX) = NULL,
	@Format varchar(MAX) , 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(MAX) = NULL ,
	@IdAgente varchar(MAX) = NULL
) AS
  DECLARE @cols varchar(max)
  DECLARE @query varchar(max)
  --ReportBySummaryAgent 'allegro','entrantes',NULL,'nov01-0356',NULL,NULL,NULL,NULL
  --SET @Format = 'nov01-0356'
  SET NOCOUNT ON
  
  SELECT
    * INTO #TempEvaluationResult
  FROM (
  SELECT
    EP.Description AS 'DescriptionPlan',
    EF.Description AS 'DescriptionFormat',
    GP.Description + '-' + SGP.Description + '-' + A.Title AS 'Ability',
    ER.AgentDescription,
    ER.CampaignDescription,
    ER.IdInteraction,
    ER.Qualification,
    Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss') AS 'EvaluationDate',
    ER.IdAuditor,
    EP.Evaluation_Mode
  FROM EvaluationResult (NOLOCK) ER
  LEFT JOIN HistoricEvaluationFormat (NOLOCK) EF
    ON ER.IdEvaluationFormat = EF.ID AND ER.IdEvaluationPlan = EF.EvaluationPlanId
  LEFT JOIN HistoricAbility (NOLOCK) A
    ON A.ID = ER.IdAbility AND ER.IdEvaluationPlan = A.EvaluationPlanId
  LEFT JOIN EvaluationPlan (NOLOCK) EP
    ON EP.ID = ER.IdEvaluationPlan
  LEFT JOIN [HistoricGroup] (NOLOCK) GP
    ON GP.ID = ER.IdGroup AND EP.ID = GP.EvaluationPlanId
  LEFT JOIN HistoricSubGroup SGP (NOLOCK)
    ON SGP.ID = ER.IdSubGroup AND EP.ID = SGP.EvaluationPlanId
	WHERE ER.Instance LIKE CASE
			WHEN @VCC IS NOT NULL THEN @VCC
			ELSE ER.Instance
			END
		AND ER.[IdEvaluationPlan] IN(SELECT [Value] FROM [dbo].[Split](IIF(@Plan IS NULL,EP.Description,@Plan),','))
		AND ER.[IdEvaluationFormat] IN (SELECT [Value] FROM [dbo].[Split](IIF(@Format IS NULL,EF.Description,@Format),','))
		AND ER.CampaignDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@HistoricCampaign IS NULL,ER.CampaignDescription,@HistoricCampaign),','))
		AND ER.AgentDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAgente IS NULL,ER.AgentDescription,@IdAgente),','))
		AND ER.IdAuditor IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAuditor IS NULL,ER.IdAuditor,@IdAuditor),','))
		AND ER.EvaluationDate >=
                          CASE
                            WHEN @StartDate IS NOT NULL THEN @StartDate
                            ELSE '19800101'
                          END
		AND ER.EvaluationDate <
                         CASE
                           WHEN @EndDate IS NOT NULL THEN @EndDate + ' 23:59'
                           ELSE '20500101'
                         END
	) a

	
	SET @cols = STUFF(
		(
			SELECT (',' + QUOTENAME(TMP_ER.[Ability]))
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')
  
  IF @cols IS NOT NULL
  BEGIN
    ------
    DECLARE @type varchar(max) = (SELECT TOP 1
      Evaluation_Mode
    FROM #TempEvaluationResult)
	
	-------
    DECLARE @Total varchar(max) = STUFF(
		(
			SELECT '+ ISNULL(' + QUOTENAME(TMP_ER.[Ability]) + ',0)'
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')    
	
	-- ROUND(AVG(CAST(ER.Qualification AS float)), 2) AS 'Qualification',
    DECLARE @colavg varchar(max) = STUFF(
		(
			SELECT ', ROUND(AVG(CAST(q.' + QUOTENAME(TMP_ER.[Ability]) + ' AS float)), 2) As [' + TMP_ER.[Ability] + ' Promedio]'
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')
	
	--SELECT @colavg
    IF @type = 'M'
    BEGIN
      SET @query = ' 
				Select 
				q.DescriptionPlan As   [EVALUATION_PLAN] ,
				q.DescriptionFormat As [EVALUATION_FORMAT] ,
				q.AgentDescription As  [AGENT] ,
				q.CampaignDescription As [CAMPAIGN] ,
				count(q.IdInteraction) As [AUDITS],
				sum(q.DurationTime) As [DURATION_TIME],
				ROUND(AVG(CAST(q.Note AS float)), 2) As [AVERAGE_SCORE],
				' + @colavg + ' From
				(Select p.DescriptionPlan,p.DescriptionFormat,p.AgentDescription,
  				p.CampaignDescription,p.IdInteraction,p.EvaluationDate,p.IdAuditor,InteractionDuration as DurationTime, 
				null As Number,InteractionDateStart As StartDate,null As Category1,(' + @Total + ') As Note, ' + @cols + ' from 
				( select DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock)
				) as A On
				A.IdInteraction=p.IdInteraction)q
				Group By 
				q.DescriptionPlan,q.DescriptionFormat,q.AgentDescription,q.CampaignDescription
				'
    END
    ELSE
    BEGIN
      SET @query = '
	
			    Select 
				q.DescriptionPlan As   [EVALUATION_PLAN] ,
				q.DescriptionFormat As [EVALUATION_FORMAT] ,
				q.AgentDescription As  [AGENT] ,
				q.CampaignDescription As [CAMPAIGN] ,
			    count(q.IdInteraction) As [AUDITS],
				sum(q.DurationTime) As [DURATION_TIME],
				ROUND(AVG(CAST(q.Note AS float)), 2) As [AVERAGE_SCORE],
				' + @colavg + '
				From 
				(Select p.DescriptionPlan,p.DescriptionFormat,p.AgentDescription,
  				p.CampaignDescription,p.IdInteraction,p.EvaluationDate,p.IdAuditor,
				A.DurationTime,A.Number,A.StartDate,A.Category1,(' + @Total + ') As Note, ' + @cols + ' from 
				( select DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join Audio as A On
				A.ID=p.IdInteraction)q
				Group By 
				q.DescriptionPlan,q.DescriptionFormat,q.AgentDescription,q.CampaignDescription'
    END
    --Print(@query)
    EXECUTE (@query)
    --Select * From @query
	

    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    DROP TABLE #TempEvaluationResult
    SELECT
						''				As [EVALUATION_PLAN],
						''				As [EVALUATION_FORMAT],
						''				As [AGENT],
  						''			    As [CAMPAIGN] 
  END
  
  SET NOCOUNT OFF
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
